==> mokkery-runtime-macosx64-1.9.22-1.5.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-answer/-sequential-by-iterator/index.md <==
//[mokkery-runtime](../../../../index.md)/[dev.mokkery.answering](../../index.md)/[Answer](../index.md)/[SequentialByIterator](index.md)

# SequentialByIterator

[common]\
data class [SequentialByIterator](index.md)&lt;[T](index.md)&gt;(val iterator: [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt;) : [Answer.Sequential](../-sequential/index.md)&lt;[T](index.md)&gt; 

Returns results of answers from [iterator](iterator.md) until empty. It supports nested [Sequential](../-sequential/index.md) answers and calls them until they are empty.

## Constructors

| | |
|---|---|
| [SequentialByIterator](-sequential-by-iterator.md) | [common]<br>constructor(iterator: [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt;) |

## Properties

| Name | Summary |
|---|---|
| [iterator](iterator.md) | [common]<br>val [iterator](iterator.md): [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt; |

## Functions

| Name | Summary |
|---|---|
| [call](call.md) | [common]<br>open override fun [call](call.md)(scope: [FunctionScope](../../-function-scope/index.md)): [T](index.md)<br>Provides a return value for a function call with given [scope](call.md). |
| [callSuspend](call-suspend.md) | [common]<br>open suspend override fun [callSuspend](call-suspend.md)(scope: [FunctionScope](../../-function-scope/index.md)): [T](index.md)<br>Just like [call](call.md) but suspends. By default, it calls [call](call.md). |
| [hasNext](has-next.md) | [common]<br>open override fun [hasNext](has-next.md)(): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>Returns true if answer should be called again. |

==> mokkery-runtime-macosx64-1.9.23-1.7.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-answer/-sequential-by-iterator/index.md <==
//[mokkery-runtime](../../../../index.md)/[dev.mokkery.answering](../../index.md)/[Answer](../index.md)/[SequentialByIterator](index.md)

# SequentialByIterator

[common]\
class [SequentialByIterator](index.md)&lt;[T](index.md)&gt;(val iterator: [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt;) : [Answer.Sequential](../-sequential/index.md)&lt;[T](index.md)&gt; 

Returns results of answers from [iterator](iterator.md) until empty. It supports nested [Sequential](../-sequential/index.md) answers and calls them until they are empty.

## Constructors

| | |
|---|---|
| [SequentialByIterator](-sequential-by-iterator.md) | [common]<br>constructor(iterator: [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt;) |

## Properties

| Name | Summary |
|---|---|
| [iterator](iterator.md) | [common]<br>val [iterator](iterator.md): [Iterator](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterator/index.html)&lt;[Answer](../index.md)&lt;[T](index.md)&gt;&gt; |

## Functions

| Name | Summary |
|---|---|
| [call](call.md) | [common]<br>open override fun [call](call.md)(scope: [FunctionScope](../../-function-scope/index.md)): [T](index.md)<br>Provides a return value for a function call with given [scope](call.md). |
| [callSuspend](call-suspend.md) | [common]<br>open suspend override fun [callSuspend](call-suspend.md)(scope: [FunctionScope](../../-function-scope/index.md)): [T](index.md)<br>Just like [call](call.md) but suspends. By default, it calls [call](call.md). |
| [equals](equals.md) | [common]<br>open operator override fun [equals](equals.md)(other: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | [common]<br>open override fun [hashCode](hash-code.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [hasNext](has-next.md) | [common]<br>open override fun [hasNext](has-next.md)(): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>Returns true if answer should be called again. |
| [toString](to-string.md) | [common]<br>open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
